@@ -48,10 +48,11 @@ class JestspectationContainer(JestspectationBase, Generic[T]):
         """
         return True
 
-    def _get_sub_diff(
+    def _format_sub_diff(
         self,
         item: object,
         other: T,
+        other_is_lhs: bool,
     ) -> list[str]:
         """
         Returns the sub-diff for the given item compared to its actual value.
@@ -61,6 +62,16 @@ class JestspectationContainer(JestspectationBase, Generic[T]):
             "present but incorrect items"
         )
 
+    def _format_missing_item(
+        self,
+        item: object,
+    ) -> str:
+        """
+        Returns a string representing the missing item. By default this is just
+        the repr.
+        """
+        return repr(item)
+
     @abstractmethod
     def _get_items(self) -> T:
         """
@@ -101,7 +112,7 @@ class JestspectationContainer(JestspectationBase, Generic[T]):
         ))
 
     @safe_diff_wrapper
-    def get_diff(self, other: object) -> list[str]:
+    def get_diff(self, other: object, other_is_lhs: bool) -> list[str]:
         if not self.__is_allowed_type(other):
             return [
                 "Type mismatch",
@@ -120,11 +131,11 @@ class JestspectationContainer(JestspectationBase, Generic[T]):
         ret += [f"Expected a {repr(self)}"]
 
         if len(misses) != 0:
-            ret += [f"-- {repr(i)}" for i in misses]
+            ret += [f"-- {self._format_missing_item(i)}" for i in misses]
 
         if len(incorrect) != 0:
             for i in incorrect:
-                sub_diff = self._get_sub_diff(i, other)
+                sub_diff = self._format_sub_diff(i, other, other_is_lhs)
                 assert sub_diff is not None
                 # Add a dot point to the first one to make it pretty
                 sub_diff[0] = '!! ' + sub_diff[0][3:]
@@ -302,10 +313,29 @@ class DictContainingItems(JestspectationContainer):
     def _is_correct(self, item: object, other: ItemsView) -> bool:
         return other[item[0]] == item[1]  # type: ignore
 
-    def _get_sub_diff(self, item: object, other: ItemsView) -> list[str]:
-        diff = sub_diff_delegate(item[1], other[item[0]])  # type: ignore
+    def _format_sub_diff(
+        self,
+        item: object,
+        other: ItemsView,
+        other_is_lhs: bool,
+    ) -> list[str]:
+        # Lots of type: ignores here because I can't figure out how to make
+        # this type-safe :(
+        # Just need to get good test coverage
+        diff = sub_diff_delegate(
+            item[1],  # type: ignore
+            other[item[0]],  # type: ignore
+            other_is_lhs,
+        )
         assert diff is not None
-        return [
-            f"   {repr(item[0])}: {repr(item[1])} "  # type: ignore
-            f"== {repr(item[0])}: {repr(other[item[0]])}"  # type: ignore
-        ] + diff
+        self_repr = self._format_missing_item(item)
+        other_repr = f"{repr(item[0])}: {repr(other[item[0]])}"  # type: ignore
+        if other_is_lhs:
+            eq_expr = f"   {other_repr} == {self_repr}"
+        else:
+            eq_expr = f"   {self_repr} == {other_repr}"
+        return [eq_expr] + diff
+
+    def _format_missing_item(self, item: object) -> str:
+        # Format like dict keys
+        return f"{repr(item[0])}: {repr(item[1])}"  # type: ignore
