@@ -17,24 +17,33 @@ from .__containers import (
 from .__float_approx import FloatApprox
 from .__equals import Equals, Is
 from .logicals import And, Not, Or, Xor
-from .__str_match import StringMatchingRegex, StringContaining
+from .__strings import (
+    StringMatchingRegex,
+    StringContaining,
+    TextLike,
+    LinesLike,
+)
+from .__config import configure
 
 
 __all__ = [
     'And',
     'Any',
     'Anything',
+    'configure',
     'DictContainingKeys',
     'DictContainingValues',
     'DictContainingItems',
     'Equals',
     'FloatApprox',
     'Is',
+    'LinesLike',
     'ListContaining',
     'Not',
     'Or',
     'SetContaining',
     'StringContaining',
     'StringMatchingRegex',
+    'TextLike',
     'Xor',
 ]
